@@ -21,20 +21,21 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
+#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_EDITABLE_H__
 #define __GTK_EDITABLE_H__
 
 
-#include <gdk/gdk.h>
 #include <gtk/gtkwidget.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
 
+G_BEGIN_DECLS
 
 #define GTK_TYPE_EDITABLE             (gtk_editable_get_type ())
 #define GTK_EDITABLE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_EDITABLE, GtkEditable))
@@ -49,7 +50,7 @@ typedef struct _GtkEditableClass  GtkEditableClass;
 struct _GtkEditableClass
 {
   GTypeInterface		   base_iface;
-  
+
   /* signals */
   void (* insert_text)              (GtkEditable    *editable,
 				     const gchar    *text,
@@ -83,13 +84,13 @@ struct _GtkEditableClass
   gint (* get_position)             (GtkEditable    *editable);
 };
 
-GtkType  gtk_editable_get_type             (void) G_GNUC_CONST;
+GType    gtk_editable_get_type             (void) G_GNUC_CONST;
 void     gtk_editable_select_region        (GtkEditable *editable,
-					    gint         start,
-					    gint         end);
+					    gint         start_pos,
+					    gint         end_pos);
 gboolean gtk_editable_get_selection_bounds (GtkEditable *editable,
-					    gint        *start,
-					    gint        *end);
+					    gint        *start_pos,
+					    gint        *end_pos);
 void     gtk_editable_insert_text          (GtkEditable *editable,
 					    const gchar *new_text,
 					    gint         new_text_length,
@@ -111,9 +112,6 @@ void     gtk_editable_set_editable         (GtkEditable *editable,
 					    gboolean     is_editable);
 gboolean gtk_editable_get_editable         (GtkEditable *editable);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+G_END_DECLS
 
 #endif /* __GTK_EDITABLE_H__ */
